package com.example.collectionofshortstories.view.catalog

import android.util.Log
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box

import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material3.Button

import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.runtime.key
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.lifecycle.viewmodel.compose.viewModel
import androidx.navigation.NavHostController
import com.example.collectionofshortstories.domain.untils.Constants
import com.example.collectionofshortstories.model.Categories
import com.example.collectionofshortstories.navigation.Routes
import io.github.jan.supabase.postgrest.from
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.withContext

@Composable
fun Catalog(navHostController: NavHostController, viewModel: CatalogViewModel = hiltViewModel()) {
    val articles by viewModel.articles.collectAsState(initial = emptyList())


    viewModel.GetUserRole()
    viewModel.GetArticles()

    Box() {
        LazyColumn(
            modifier = Modifier
                .fillMaxSize()
                .padding(16.dp)
        ) {
            items(
                articles,
                key = { articleDate -> articleDate.id }
            ) { articleDate ->
                Row(
                    horizontalArrangement = Arrangement.SpaceAround,
                    modifier = Modifier
                        .fillMaxWidth()
                ) {
                    Text(
                        text = articleDate.title,
                        modifier = Modifier
                            .padding(30.dp)
                            .weight(1f)
                    )
                }
            }
        }
        if (viewModel.showButton.value) {
            Button(
                onClick = {
                    navHostController.navigate(Routes.CREATEARTICLE)
                },
                modifier = Modifier
                    .align(Alignment.BottomEnd)
                    .padding(0.dp, 0.dp, 40.dp, 80.dp)
            ) {
                Text("Добавить рассказ")
            }
        }
    }
}